use migration::MigratorTrait;
use sea_orm::Database;
use sea_orm::DatabaseConnection;
use thiserror::Error;

#[derive(Clone)]
pub struct Data(DatabaseConnection);

#[derive(Error, Debug)]
pub enum NewDataError {
    #[error("database error: {0}")]
    Database(#[from] sea_orm::DbErr),
}

impl Data {
    pub async fn try_new(
        database_connection_string: &str,
        reset: bool,
    ) -> Result<Self, NewDataError> {
        let db = Database::connect(database_connection_string).await?;
        if reset {
            migration::Migrator::fresh(&db).await?;
        }
        migration::Migrator::up(&db, None).await?;
        Ok(Self(db))
    }
}
